$def with(product)
<br>
<h1>Product</h1>
Product: $product.product <br>
Description: $product.description <br>
Stock: $product.stock <br>
Purchase price: $product.purchase_price <br>
Price sale: $product.price_sale <br>

<img src="../../static/files/$product.product_image" width="200px" height="200px" />
<br>
<br>