$def with(form)
<br>
<form name="main" method="POST">
    $for input in form.inputs:
        <div class="form-group">
            <label for="$:input.description">$:input.description</label>
            $:input.render()
        </div>
    <div class="form-group">
        <input type="submit" value="Delete"/>
    </div>
</form>