$def with(products)
<h1>Products</h1>
<table class="table table-hoview">
	<th>Product</th>
	<th>Edit</th>
	<th>Delete</th>

	$for item in products:
	<tr>
		<td><a href='/products/view/$item.id_product'>$item.product</a></td>
		<td><a href='/products/edit/$item.id_product'><span class="glyphicon glyphicon-pencil"></span></a></td>
		<td><a href='/products/delete/$item.id_product'><span class="glyphicon glyphicon-trash"></span></a></td>
	</tr>
</table>
<br>
<br>