$def with(result)
<h1>Index</h1>
<table class="table">
    <th>Name</th>
    <th>Update</th>
    <th>Delete</th>

$for row in result:
    <tr>
        <td><a href="/view/$row.id_person" >$row.name</a></td>
        <td><a href="/update/$row.id_person" >Update</a></td>
        <td><a href="/delete/$row.id_person" >Delete</a></td>
    </tr>
<br>
<br>