$def with (form)
$var username: None

<h1>Login</h1>
<form action="" method="post" enctype="multipart/form-data">
    $for input in form.inputs:
        <div class="form-group">
                <label>$:input.description</label>
                $:input.render()
        </div>
</form>