from setuptools import setup, find_packages  # Always prefer setuptools over distutils

long_description = """
Create basic MVC skeleton using Web.py Microframework and Heroku ready:
Functions:
    bootstrap - frontend framework
    jquery - js framework
    scheme.sql - MySQL demo database
    api - Restfull API
    ssl - HTTPS conection
    requirements.txt - Heroku requirements
    Procfile - Heroku config
"""

setup(
    name="kuorra",
    version="0.4.0",
    description="Create basic MVC skeleton using Web.py Microframework",

    long_description=long_description,
    
    author="Salvador Hernandez Mendoza",
    
    author_email="salvadorhm@gmail.com",
    
    license="GPLv3",
    
    url="https://salvadorhm.github.io/kuorra",
    
    download_url="https://salvadorhm.github.io/kuorra",
    
    classifiers=['Development Status :: 4 - Beta',
                'Intended Audience :: Developers',
                'Topic :: Software Development',
                'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
                'Programming Language :: Python :: 2.7'],
    keywords="mvc web.py mysql heroku bootstrap jquery ssl api restful",
    install_requires=["web.py==0.38", "MySQL-python==1.2.5", "pyOpenSSL==16.2.0"],
    zip_safe=False,

    packages=find_packages(exclude=["*.tests", "*.tests.*", "tests.*",
                                    "tests", "*tests*"]),
    entry_points={'console_scripts': ['kuorra=kuorra.kuorra:main'],
                },
    package_data={"kuorra": [
            "__init__.py",
            "__main__.py",
            "kuorra.py",
            "model_generator.py",
            "api_generator.py",
            "plugin/model_master.py",
            "plugin/api_master_cool.py",
            "mvc/__init__.py",
            "mvc/app.py",
            "mvc/Procfile",
            "mvc/requirements.txt",
            "mvc/Readme.md",
            "mvc/ssl",
            "mvc/ssl/server.crt",
            "mvc/ssl/server.csr",
            "mvc/ssl/server.key",
            "mvc/application/__init__.py",
            "mvc/application/controllers/__init__.py",
            "mvc/application/controllers/products/config.py",
            "mvc/application/controllers/products/delete.py",
            "mvc/application/controllers/products/edit.py",
            "mvc/application/controllers/products/index.py",
            "mvc/application/controllers/products/__init__.py",
            "mvc/application/controllers/products/insert.py",
            "mvc/application/controllers/products/view.py",
            "mvc/application/models/config.py",
            "mvc/application/models/__init__.py",
            "mvc/application/models/model_products.py",
            "mvc/application/views/__init__.py",
            "mvc/application/views/products/delete.html",
            "mvc/application/views/products/edit.html",
            "mvc/application/views/products/index.html",
            "mvc/application/views/products/__init__.py",
            "mvc/application/views/products/insert.html",
            "mvc/application/views/products/master.html",
            "mvc/application/views/products/view.html",
            "mvc/application/api/__init__.py",
            "mvc/application/api/products/__init__.py",
            "mvc/application/api/products/api_products.py",
            "mvc/application/api/products/config.py",
            "mvc/data/schema.sql",
            "mvc/static/css/bootstrap.css",
            "mvc/static/css/index.html",
            "mvc/static/files/default.jpg",
            "mvc/static/fonts/glyphicons-halflings-regular.eot",
            "mvc/static/fonts/glyphicons-halflings-regular.svg",
            "mvc/static/fonts/glyphicons-halflings-regular.ttf",
            "mvc/static/fonts/glyphicons-halflings-regular.woff",
            "mvc/static/fonts/glyphicons-halflings-regular.woff2",
            "mvc/static/fonts/index.html",
            "mvc/static/js/bootstrap.js",
            "mvc/static/js/index.html",
            "mvc/static/js/jquery.js",
            "mvc_forms/__init__.py",
            "mvc_forms/app.py",
            "mvc_forms/Procfile",
            "mvc_forms/requirements.txt",
            "mvc_forms/Readme.md",
            "mvc_forms/ssl",
            "mvc_forms/ssl/server.crt",
            "mvc_forms/ssl/server.csr",
            "mvc_forms/ssl/server.key",
            "mvc_forms/application/__init__.py",
            "mvc_forms/application/controllers/__init__.py",
            "mvc_forms/application/controllers/persons/config.py",
            "mvc_forms/application/controllers/persons/delete.py",
            "mvc_forms/application/controllers/persons/update.py",
            "mvc_forms/application/controllers/persons/index.py",
            "mvc_forms/application/controllers/persons/__init__.py",
            "mvc_forms/application/controllers/persons/insert.py",
            "mvc_forms/application/controllers/persons/view.py",
            "mvc_forms/application/models/config.py",
            "mvc_forms/application/models/__init__.py",
            "mvc_forms/application/models/model_persons.py",
            "mvc_forms/application/views/__init__.py",
            "mvc_forms/application/views/persons/delete.html",
            "mvc_forms/application/views/persons/update.html",
            "mvc_forms/application/views/persons/index.html",
            "mvc_forms/application/views/persons/__init__.py",
            "mvc_forms/application/views/persons/insert.html",
            "mvc_forms/application/views/persons/master.html",
            "mvc_forms/application/views/persons/view.html",
            "mvc_forms/application/api/__init__.py",
            "mvc_forms/application/api/persons/__init__.py",
            "mvc_forms/application/api/persons/api_persons.py",
            "mvc_forms/application/api/persons/config.py",
            "mvc_forms/data/schema.sql",
            "mvc_forms/static/css/bootstrap.css",
            "mvc_forms/static/css/index.html",
            "mvc_forms/static/files/default.jpg",
            "mvc_forms/static/fonts/glyphicons-halflings-regular.eot",
            "mvc_forms/static/fonts/glyphicons-halflings-regular.svg",
            "mvc_forms/static/fonts/glyphicons-halflings-regular.ttf",
            "mvc_forms/static/fonts/glyphicons-halflings-regular.woff",
            "mvc_forms/static/fonts/glyphicons-halflings-regular.woff2",
            "mvc_forms/static/fonts/index.html",
            "mvc_forms/static/js/bootstrap.js",
            "mvc_forms/static/js/index.html",
            "mvc_forms/static/js/jquery.js",
            "mvc_base/__init__.py",
            "mvc_base/app.py",
            "mvc_base/Procfile",
            "mvc_base/requirements.txt",
            "mvc_base/Readme.md",
            "mvc_base/ssl",
            "mvc_base/ssl/server.crt",
            "mvc_base/ssl/server.csr",
            "mvc_base/ssl/server.key",
            "mvc_base/application/__init__.py",
            "mvc_base/application/controllers/__init__.py",
            "mvc_base/application/controllers/main/config.py",
            "mvc_base/application/controllers/main/index.py",
            "mvc_base/application/controllers/main/__init__.py",
            "mvc_base/application/models/config.py",
            "mvc_base/application/models/__init__.py",
            "mvc_base/application/views/__init__.py",
            "mvc_base/application/views/main/index.html",
            "mvc_base/application/views/main/master.html",
            "mvc_base/application/views/main/__init__.py",
            "mvc_base/application/api/__init__.py",
            "mvc_base/data/schema.sql",
            "mvc_base/static/css/bootstrap.css",
            "mvc_base/static/css/index.html",
            "mvc_base/static/files/default.jpg",
            "mvc_base/static/fonts/glyphicons-halflings-regular.eot",
            "mvc_base/static/fonts/glyphicons-halflings-regular.svg",
            "mvc_base/static/fonts/glyphicons-halflings-regular.ttf",
            "mvc_base/static/fonts/glyphicons-halflings-regular.woff",
            "mvc_base/static/fonts/glyphicons-halflings-regular.woff2",
            "mvc_base/static/fonts/index.html",
            "mvc_base/static/js/bootstrap.js",
            "mvc_base/static/js/index.html",
            "mvc_base/static/js/jquery.js",
            "mvc_sessions/__init__.py",
            "mvc_sessions/app.py",
            "mvc_sessions/Procfile",
            "mvc_sessions/requirements.txt",
            "mvc_sessions/Readme.md",
            "mvc_sessions/config.py",
            "mvc_sessions/ssl",
            "mvc_sessions/ssl/server.crt",
            "mvc_sessions/ssl/server.csr",
            "mvc_sessions/ssl/server.key",
            "mvc_sessions/application/__init__.py",
            "mvc_sessions/application/controllers/__init__.py",
            "mvc_sessions/application/controllers/main/config.py",
            "mvc_sessions/application/controllers/main/guess.py",
            "mvc_sessions/application/controllers/main/index.py",
            "mvc_sessions/application/controllers/main/login.py",
            "mvc_sessions/application/controllers/main/logout.py",
            "mvc_sessions/application/controllers/main/__init__.py",
            "mvc_sessions/application/models/config.py",
            "mvc_sessions/application/models/model_users.py",
            "mvc_sessions/application/models/__init__.py",
            "mvc_sessions/application/views/__init__.py",
            "mvc_sessions/application/views/main/guess.html",
            "mvc_sessions/application/views/main/index.html",
            "mvc_sessions/application/views/main/login.html",
            "mvc_sessions/application/views/main/master.html",
            "mvc_sessions/application/views/main/__init__.py",
            "mvc_sessions/application/api/__init__.py",
            "mvc_sessions/data/schema.sql",
            "mvc_sessions/static/css/bootstrap.css",
            "mvc_sessions/static/css/index.html",
            "mvc_sessions/static/files/default.jpg",
            "mvc_sessions/static/fonts/glyphicons-halflings-regular.eot",
            "mvc_sessions/static/fonts/glyphicons-halflings-regular.svg",
            "mvc_sessions/static/fonts/glyphicons-halflings-regular.ttf",
            "mvc_sessions/static/fonts/glyphicons-halflings-regular.woff",
            "mvc_sessions/static/fonts/glyphicons-halflings-regular.woff2",
            "mvc_sessions/static/fonts/index.html",
            "mvc_sessions/static/js/bootstrap.js",
            "mvc_sessions/static/js/index.html",
            "mvc_sessions/static/js/jquery.js"
            ]}
)